Class: A2A::TextPart

Inherits:
PartBase
  • Object
show all
Defined in:
lib/a2a/types/text_part.rb

Overview

Represents a text segment within a message or artifact.

Instance Method Summary collapse

Methods inherited from PartBase

#metadata

Methods included from Extensions::CaseTransformation

#camelize, included, #to_json

Instance Method Details

#kind ⇒ String

Returns The type of this part, used as a discriminator. Always 'text'.

Returns:

  • (String) —

    The type of this part, used as a discriminator. Always 'text'.



7
# File 'lib/a2a/types/text_part.rb', line 7

attribute :kind, Types::String.constant('text')

#text ⇒ String

Returns The string content of the text part.

Returns:

  • (String) —

    The string content of the text part.



10
# File 'lib/a2a/types/text_part.rb', line 10

attribute :text, Types::String